Method: AmazonPayClient#get_refund

Defined in:
lib/amazon-pay-api-sdk-ruby/client.rb

#get_refund(refund_id, headers: {}) ⇒ HTTPResponse

API to retrieve refund details Retrieves details of an existing refund using its unique refund ID.

Parameters:

  • refund_id (String)
    • The unique ID of the refund to retrieve.

  • headers (Object) (defaults to: {})
    • Optional headers for the request, such as authorization tokens or custom headers.

Returns:

  • (HTTPResponse)

    The response from the API call, which includes details of the requested refund.

See Also:



277
278
279
# File 'lib/amazon-pay-api-sdk-ruby/client.rb', line 277

def get_refund(refund_id, headers: {})
  api_call("#{Constants::REFUNDS_URL}/#{refund_id}", Constants::GET, headers: headers)
end